@@ -1,6 +1,8 @@
 import abc
 from numbers import Number
 
+from hackle.evaluation.match.semantic_version import SemanticVersion
+
 
 class ValueMatcher(object, metaclass=abc.ABCMeta):
 
@@ -31,3 +33,13 @@ class BoolValueMatcher(ValueMatcher):
             return operator_matcher.bool_matches(user_value, match_value)
         else:
             return False
+
+
+class VersionValueMatcher(ValueMatcher):
+    def matches(self, operator_matcher, user_value, match_value):
+        user_version = SemanticVersion.parse_or_none(user_value)
+        match_version = SemanticVersion.parse_or_none(match_value)
+        if user_version is not None and match_version is not None:
+            return operator_matcher.version_matches(user_version, match_version)
+        else:
+            return False
