@@ -1,5 +1,6 @@
 from hackle.commons import validator, utils
 from hackle.decision import ExperimentDecision, FeatureFlagDecision, DecisionReason
+from hackle.entities import EventType
 from hackle.event.user_event import ExposureEvent, TrackEvent
 
 
@@ -104,12 +105,20 @@ class InternalClient(object):
                 ': {}'.format(user.properties))
             user.properties = utils.filter_properties(user.properties)
 
-        config = self.workspace_fetcher.get_workspace()
-        if not config:
-            self.logger.warning('Invalid Workspace. Hackle instance is not valid. {}'.format('event'))
-            return
-
-        event_type = config.get_event_type_or_none(event.key)
+        event_type = self._event_type(event)
         self.event_processor.process(TrackEvent(user, event_type, event))
 
         return
+
+    def _event_type(self, event):
+        config = self.workspace_fetcher.get_workspace()
+
+        if not config:
+            return EventType(0, event.key)
+
+        event_type = config.get_event_type_or_none(event.key)
+
+        if not event_type:
+            return EventType(0, event.key)
+
+        return event_type
