@@ -5,25 +5,24 @@ import traceback
 import requests
 from requests import exceptions as requests_exceptions
 
+from hackle import logger as hackle_logger
 from hackle import version
-from . import logger as hackle_logger
-from . import workspace
-from .commons import enums
+from hackle.commons import enums
+from hackle.workspace import Workspace
 
 
 class WorkspaceFetcher(object):
-    WORKSPACE_URL = enums.Default.WORKSPACE_URL
-
-    def __init__(self, sdk_key=None, update_interval=None, blocking_timeout=None, logger=None, ssl_verify=True):
+    def __init__(self, sdk_key=None, update_interval=None, blocking_timeout=None, logger=None, timeout=None):
         self.sdk_key = sdk_key
+        self.workspace_url = enums.Default.WORKSPACE_URL
         self.update_interval = update_interval or enums.Default.DEFAULT_POLL_INTERVAL
         self.blocking_timeout = blocking_timeout or enums.Default.DEFAULT_BLOCKING_TIMEOUT
         self.logger = hackle_logger.adapt_logger(logger or hackle_logger.NoOpLogger())
+        self.timeout = timeout
         self._workspace_fetch_ready_event = threading.Event()
         self._polling_thread = threading.Thread(target=self._run)
         self._polling_thread.setDaemon(True)
         self._polling_thread.start()
-        self.ssl_verify = ssl_verify
 
     def _handle_response(self, response):
         try:
@@ -32,7 +31,7 @@ class WorkspaceFetcher(object):
             self.logger.error('Failed to pool Workspace: {}'.format(err))
             return
 
-        self._set_config(response.content)
+        self._set_workspace(response.content)
 
     def fetch(self):
         request_headers = {enums.Default.SDK_KEY_HEADER: self.sdk_key,
@@ -40,10 +39,9 @@ class WorkspaceFetcher(object):
                            enums.Default.SDK_VERSION_HEADER: version.__version__}
         try:
             response = requests.get(
-                self.WORKSPACE_URL,
+                self.workspace_url,
                 headers=request_headers,
-                timeout=enums.Default.REQUEST_TIMEOUT,
-                verify=self.ssl_verify
+                timeout=self.timeout or enums.Default.REQUEST_TIMEOUT
             )
         except requests_exceptions.RequestException:
             self.logger.error('Failed to pool Workspace: {}'.format(traceback.format_exc()))
@@ -68,12 +66,12 @@ class WorkspaceFetcher(object):
         if not self.is_running:
             self._polling_thread.start()
 
-    def _set_config(self, content):
+    def _set_workspace(self, content):
         if content or self._workspace_fetch_ready_event.is_set():
-            self._workspace = workspace.Workspace(content, self.logger)
+            self._workspace = Workspace(content)
             self._workspace_fetch_ready_event.set()
 
-    def get_config(self):
+    def get_workspace(self):
         self._workspace_fetch_ready_event.wait(self.blocking_timeout)
         if hasattr(self, '_workspace'):
             return self._workspace
